Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Verifier ¶
type Verifier interface {
// Verify verifies a given Signature applies to a given Signable, the string argument is the required subject name
// prefix . The suffix is always checked and has to be .metal.local.
// for example, if the required prefix is "admin-" the subject must be something like admin-1.metal.local
Verify(*Signature, Signable, string) error
}
func PKIVerifierFromFile ¶
Click to show internal directories.
Click to hide internal directories.